Module tracker

Module tracker 

Constants

ALL_TRACKER_DDL
All tracker DDL statements in the order they must be executed.
DDL_MIGRATION_ERROR_LOG
DDL for public.migration_error_log.
DDL_MIGRATION_RUNTIME_STATE
DDL for public.migration_runtime_state.
DDL_PROTO_SCHEMA_VERSIONS
DDL for public.proto_schema_versions.
DDL_SCHEMA_MIGRATIONS
DDL for public.schema_migrations.
DEFAULT_LEDGER_SCHEMA

Functions

all_tracker_ddl_sql
Returns all tracker DDL joined by a blank line separator, ready for output by the tracker-ddl CLI command or for direct psql execution.
all_tracker_ddl_sql_for_schema